# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.10.3-v202502171101-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ColumnRuleScalarCreatorInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'column_index': 'int',
        'column_index_data_id': 'int',
        'description': 'str',
        'identity_id': 'str',
        'name': 'str',
        'permission_string': 'str',
        'scoped_to': 'str'
    }

    attribute_map = {
        'column_index': 'columnIndex',
        'column_index_data_id': 'columnIndexDataId',
        'description': 'description',
        'identity_id': 'identityId',
        'name': 'name',
        'permission_string': 'permissionString',
        'scoped_to': 'scopedTo'
    }

    def __init__(self, column_index=None, column_index_data_id=None, description=None, identity_id=None, name=None, permission_string=None, scoped_to=None):
        """
        ColumnRuleScalarCreatorInputV1 - a model defined in Swagger
        """

        self._column_index = None
        self._column_index_data_id = None
        self._description = None
        self._identity_id = None
        self._name = None
        self._permission_string = None
        self._scoped_to = None

        if column_index is not None:
          self.column_index = column_index
        if column_index_data_id is not None:
          self.column_index_data_id = column_index_data_id
        if description is not None:
          self.description = description
        if identity_id is not None:
          self.identity_id = identity_id
        if name is not None:
          self.name = name
        if permission_string is not None:
          self.permission_string = permission_string
        if scoped_to is not None:
          self.scoped_to = scoped_to

    @property
    def column_index(self):
        """
        Gets the column_index of this ColumnRuleScalarCreatorInputV1.
        The index of the column that contains the value to use when creating the scalar. The column index is 1-based.

        :return: The column_index of this ColumnRuleScalarCreatorInputV1.
        :rtype: int
        """
        return self._column_index

    @column_index.setter
    def column_index(self, column_index):
        """
        Sets the column_index of this ColumnRuleScalarCreatorInputV1.
        The index of the column that contains the value to use when creating the scalar. The column index is 1-based.

        :param column_index: The column_index of this ColumnRuleScalarCreatorInputV1.
        :type: int
        """
        if column_index is None:
            raise ValueError("Invalid value for `column_index`, must not be `None`")

        self._column_index = column_index

    @property
    def column_index_data_id(self):
        """
        Gets the column_index_data_id of this ColumnRuleScalarCreatorInputV1.
        The optional index of the column that should be used to create the data ID for the scalar. The column index is 1-based. Provide this to reuse created scalars across rows with the same data ID. Otherwise, a new scalar will be created per row.

        :return: The column_index_data_id of this ColumnRuleScalarCreatorInputV1.
        :rtype: int
        """
        return self._column_index_data_id

    @column_index_data_id.setter
    def column_index_data_id(self, column_index_data_id):
        """
        Sets the column_index_data_id of this ColumnRuleScalarCreatorInputV1.
        The optional index of the column that should be used to create the data ID for the scalar. The column index is 1-based. Provide this to reuse created scalars across rows with the same data ID. Otherwise, a new scalar will be created per row.

        :param column_index_data_id: The column_index_data_id of this ColumnRuleScalarCreatorInputV1.
        :type: int
        """

        self._column_index_data_id = column_index_data_id

    @property
    def description(self):
        """
        Gets the description of this ColumnRuleScalarCreatorInputV1.
        Clarifying information or other plain language description for items created by this rule. An input of just whitespace is equivalent to a null input.

        :return: The description of this ColumnRuleScalarCreatorInputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ColumnRuleScalarCreatorInputV1.
        Clarifying information or other plain language description for items created by this rule. An input of just whitespace is equivalent to a null input.

        :param description: The description of this ColumnRuleScalarCreatorInputV1.
        :type: str
        """

        self._description = description

    @property
    def identity_id(self):
        """
        Gets the identity_id of this ColumnRuleScalarCreatorInputV1.
        The ID of the identity for which permissions will be set on items created by this rule. A null value means that the items created by this rule will have the same permissions as its associated datasource. Must be set along with permissionString.

        :return: The identity_id of this ColumnRuleScalarCreatorInputV1.
        :rtype: str
        """
        return self._identity_id

    @identity_id.setter
    def identity_id(self, identity_id):
        """
        Sets the identity_id of this ColumnRuleScalarCreatorInputV1.
        The ID of the identity for which permissions will be set on items created by this rule. A null value means that the items created by this rule will have the same permissions as its associated datasource. Must be set along with permissionString.

        :param identity_id: The identity_id of this ColumnRuleScalarCreatorInputV1.
        :type: str
        """

        self._identity_id = identity_id

    @property
    def name(self):
        """
        Gets the name of this ColumnRuleScalarCreatorInputV1.
        Human readable name for items created by this rule. Null or whitespace names are not permitted.

        :return: The name of this ColumnRuleScalarCreatorInputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ColumnRuleScalarCreatorInputV1.
        Human readable name for items created by this rule. Null or whitespace names are not permitted.

        :param name: The name of this ColumnRuleScalarCreatorInputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def permission_string(self):
        """
        Gets the permission_string of this ColumnRuleScalarCreatorInputV1.
        The permissions for the identity included for items created by this rule. Must be in a valid string form with each permission separated by a comma, for example 'r,w,m'. Acceptable permissions are: 'r' - read, 'w' - write, 'm' - manage.Must be set along with identityId.

        :return: The permission_string of this ColumnRuleScalarCreatorInputV1.
        :rtype: str
        """
        return self._permission_string

    @permission_string.setter
    def permission_string(self, permission_string):
        """
        Sets the permission_string of this ColumnRuleScalarCreatorInputV1.
        The permissions for the identity included for items created by this rule. Must be in a valid string form with each permission separated by a comma, for example 'r,w,m'. Acceptable permissions are: 'r' - read, 'w' - write, 'm' - manage.Must be set along with identityId.

        :param permission_string: The permission_string of this ColumnRuleScalarCreatorInputV1.
        :type: str
        """

        self._permission_string = permission_string

    @property
    def scoped_to(self):
        """
        Gets the scoped_to of this ColumnRuleScalarCreatorInputV1.
        The ID of the workbook to which this item will be scoped. Null if the item should be globally scoped.

        :return: The scoped_to of this ColumnRuleScalarCreatorInputV1.
        :rtype: str
        """
        return self._scoped_to

    @scoped_to.setter
    def scoped_to(self, scoped_to):
        """
        Sets the scoped_to of this ColumnRuleScalarCreatorInputV1.
        The ID of the workbook to which this item will be scoped. Null if the item should be globally scoped.

        :param scoped_to: The scoped_to of this ColumnRuleScalarCreatorInputV1.
        :type: str
        """

        self._scoped_to = scoped_to

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ColumnRuleScalarCreatorInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.10.3-v202502171101-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ScalarPropertyV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'unit_of_measure': 'str',
        'value': 'object'
    }

    attribute_map = {
        'name': 'name',
        'unit_of_measure': 'unitOfMeasure',
        'value': 'value'
    }

    def __init__(self, name=None, unit_of_measure=None, value=None):
        """
        ScalarPropertyV1 - a model defined in Swagger
        """

        self._name = None
        self._unit_of_measure = None
        self._value = None

        if name is not None:
          self.name = name
        if unit_of_measure is not None:
          self.unit_of_measure = unit_of_measure
        if value is not None:
          self.value = value

    @property
    def name(self):
        """
        Gets the name of this ScalarPropertyV1.
        Human readable name of the property. Null or whitespace names are not permitted

        :return: The name of this ScalarPropertyV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ScalarPropertyV1.
        Human readable name of the property. Null or whitespace names are not permitted

        :param name: The name of this ScalarPropertyV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def unit_of_measure(self):
        """
        Gets the unit_of_measure of this ScalarPropertyV1.
        The unit of measure to apply to this property's value. If no unit of measure is set and the value is numeric, it is assumed to be unitless

        :return: The unit_of_measure of this ScalarPropertyV1.
        :rtype: str
        """
        return self._unit_of_measure

    @unit_of_measure.setter
    def unit_of_measure(self, unit_of_measure):
        """
        Sets the unit_of_measure of this ScalarPropertyV1.
        The unit of measure to apply to this property's value. If no unit of measure is set and the value is numeric, it is assumed to be unitless

        :param unit_of_measure: The unit_of_measure of this ScalarPropertyV1.
        :type: str
        """

        self._unit_of_measure = unit_of_measure

    @property
    def value(self):
        """
        Gets the value of this ScalarPropertyV1.
        The value to assign to this property. If the value is surrounded by quotes, it is interpreted as a string and no units are set

        :return: The value of this ScalarPropertyV1.
        :rtype: object
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this ScalarPropertyV1.
        The value to assign to this property. If the value is surrounded by quotes, it is interpreted as a string and no units are set

        :param value: The value of this ScalarPropertyV1.
        :type: object
        """
        if value is None:
            raise ValueError("Invalid value for `value`, must not be `None`")

        self._value = value

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ScalarPropertyV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.10.3-v202502171101-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ItemFinderSearchesInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'fixed_list_searches': 'list[FixedListSearchV1]',
        'limit': 'int',
        'property_searches': 'list[PropertySearchV1]',
        'scaling_table_uuid_column_searches': 'list[ScalingTableUUIDColumnSearchV1]',
        'searches': 'list[SwapAcrossAssetsSearchV1]'
    }

    attribute_map = {
        'fixed_list_searches': 'fixedListSearches',
        'limit': 'limit',
        'property_searches': 'propertySearches',
        'scaling_table_uuid_column_searches': 'scalingTableUUIDColumnSearches',
        'searches': 'searches'
    }

    def __init__(self, fixed_list_searches=None, limit=40, property_searches=None, scaling_table_uuid_column_searches=None, searches=None):
        """
        ItemFinderSearchesInputV1 - a model defined in Swagger
        """

        self._fixed_list_searches = None
        self._limit = None
        self._property_searches = None
        self._scaling_table_uuid_column_searches = None
        self._searches = None

        if fixed_list_searches is not None:
          self.fixed_list_searches = fixed_list_searches
        if limit is not None:
          self.limit = limit
        if property_searches is not None:
          self.property_searches = property_searches
        if scaling_table_uuid_column_searches is not None:
          self.scaling_table_uuid_column_searches = scaling_table_uuid_column_searches
        if searches is not None:
          self.searches = searches

    @property
    def fixed_list_searches(self):
        """
        Gets the fixed_list_searches of this ItemFinderSearchesInputV1.
        The list of searches containing a list of item IDs to always include or exclude in the output

        :return: The fixed_list_searches of this ItemFinderSearchesInputV1.
        :rtype: list[FixedListSearchV1]
        """
        return self._fixed_list_searches

    @fixed_list_searches.setter
    def fixed_list_searches(self, fixed_list_searches):
        """
        Sets the fixed_list_searches of this ItemFinderSearchesInputV1.
        The list of searches containing a list of item IDs to always include or exclude in the output

        :param fixed_list_searches: The fixed_list_searches of this ItemFinderSearchesInputV1.
        :type: list[FixedListSearchV1]
        """

        self._fixed_list_searches = fixed_list_searches

    @property
    def limit(self):
        """
        Gets the limit of this ItemFinderSearchesInputV1.
        The maximum number of search results that will be returned

        :return: The limit of this ItemFinderSearchesInputV1.
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """
        Sets the limit of this ItemFinderSearchesInputV1.
        The maximum number of search results that will be returned

        :param limit: The limit of this ItemFinderSearchesInputV1.
        :type: int
        """

        self._limit = limit

    @property
    def property_searches(self):
        """
        Gets the property_searches of this ItemFinderSearchesInputV1.
        The list of searches based on properties

        :return: The property_searches of this ItemFinderSearchesInputV1.
        :rtype: list[PropertySearchV1]
        """
        return self._property_searches

    @property_searches.setter
    def property_searches(self, property_searches):
        """
        Sets the property_searches of this ItemFinderSearchesInputV1.
        The list of searches based on properties

        :param property_searches: The property_searches of this ItemFinderSearchesInputV1.
        :type: list[PropertySearchV1]
        """

        self._property_searches = property_searches

    @property
    def scaling_table_uuid_column_searches(self):
        """
        Gets the scaling_table_uuid_column_searches of this ItemFinderSearchesInputV1.
        The list of searches for finding items based on a materialized table's UUID column

        :return: The scaling_table_uuid_column_searches of this ItemFinderSearchesInputV1.
        :rtype: list[ScalingTableUUIDColumnSearchV1]
        """
        return self._scaling_table_uuid_column_searches

    @scaling_table_uuid_column_searches.setter
    def scaling_table_uuid_column_searches(self, scaling_table_uuid_column_searches):
        """
        Sets the scaling_table_uuid_column_searches of this ItemFinderSearchesInputV1.
        The list of searches for finding items based on a materialized table's UUID column

        :param scaling_table_uuid_column_searches: The scaling_table_uuid_column_searches of this ItemFinderSearchesInputV1.
        :type: list[ScalingTableUUIDColumnSearchV1]
        """

        self._scaling_table_uuid_column_searches = scaling_table_uuid_column_searches

    @property
    def searches(self):
        """
        Gets the searches of this ItemFinderSearchesInputV1.
        The list of searches for swapping across assets to find items

        :return: The searches of this ItemFinderSearchesInputV1.
        :rtype: list[SwapAcrossAssetsSearchV1]
        """
        return self._searches

    @searches.setter
    def searches(self, searches):
        """
        Sets the searches of this ItemFinderSearchesInputV1.
        The list of searches for swapping across assets to find items

        :param searches: The searches of this ItemFinderSearchesInputV1.
        :type: list[SwapAcrossAssetsSearchV1]
        """

        self._searches = searches

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ItemFinderSearchesInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.10.3-v202502171101-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class FormulaToken(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'column': 'int',
        'line': 'int',
        'text': 'str',
        'trace_id': 'str'
    }

    attribute_map = {
        'column': 'column',
        'line': 'line',
        'text': 'text',
        'trace_id': 'traceId'
    }

    def __init__(self, column=None, line=None, text=None, trace_id=None):
        """
        FormulaToken - a model defined in Swagger
        """

        self._column = None
        self._line = None
        self._text = None
        self._trace_id = None

        if column is not None:
          self.column = column
        if line is not None:
          self.line = line
        if text is not None:
          self.text = text
        if trace_id is not None:
          self.trace_id = trace_id

    @property
    def column(self):
        """
        Gets the column of this FormulaToken.

        :return: The column of this FormulaToken.
        :rtype: int
        """
        return self._column

    @column.setter
    def column(self, column):
        """
        Sets the column of this FormulaToken.

        :param column: The column of this FormulaToken.
        :type: int
        """

        self._column = column

    @property
    def line(self):
        """
        Gets the line of this FormulaToken.

        :return: The line of this FormulaToken.
        :rtype: int
        """
        return self._line

    @line.setter
    def line(self, line):
        """
        Sets the line of this FormulaToken.

        :param line: The line of this FormulaToken.
        :type: int
        """

        self._line = line

    @property
    def text(self):
        """
        Gets the text of this FormulaToken.

        :return: The text of this FormulaToken.
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """
        Sets the text of this FormulaToken.

        :param text: The text of this FormulaToken.
        :type: str
        """

        self._text = text

    @property
    def trace_id(self):
        """
        Gets the trace_id of this FormulaToken.

        :return: The trace_id of this FormulaToken.
        :rtype: str
        """
        return self._trace_id

    @trace_id.setter
    def trace_id(self, trace_id):
        """
        Sets the trace_id of this FormulaToken.

        :param trace_id: The trace_id of this FormulaToken.
        :type: str
        """

        self._trace_id = trace_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, FormulaToken):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.10.3-v202502171101-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import sys
import os
import re

from deprecated import deprecated
# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient
from ..models import *

class DatafilesApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def archive_datafile(self, **kwargs):
        """
        Archive a datafile and all of its signals
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.archive_datafile(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: ID of the datafile to archive (required)
        :return: StatusMessageBase
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: StatusMessageBase
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.archive_datafile_with_http_info(**kwargs)
        else:
            (data) = self.archive_datafile_with_http_info(**kwargs)
            return data

    def archive_datafile_with_http_info(self, **kwargs):
        """
        Archive a datafile and all of its signals
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.archive_datafile_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: ID of the datafile to archive (required)
        :return: StatusMessageBase
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: StatusMessageBase
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method archive_datafile" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `archive_datafile`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/datafiles/{id}', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'StatusMessageBase'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def create_datafile(self, **kwargs):
        """
        Create a datafile
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_datafile(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param DatafileInputV1 body: Datafile information (required)
        :return: DatafileOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DatafileOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.create_datafile_with_http_info(**kwargs)
        else:
            (data) = self.create_datafile_with_http_info(**kwargs)
            return data

    def create_datafile_with_http_info(self, **kwargs):
        """
        Create a datafile
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_datafile_with_http_info(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param DatafileInputV1 body: Datafile information (required)
        :return: DatafileOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DatafileOutputV1
        """

        all_params = ['body']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_datafile" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_datafile`")


        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/datafiles', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'DatafileOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_datafile(self, **kwargs):
        """
        Get a Datafile
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_datafile(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: ID of the datafile to retrieve (required)
        :return: DatafileOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DatafileOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_datafile_with_http_info(**kwargs)
        else:
            (data) = self.get_datafile_with_http_info(**kwargs)
            return data

    def get_datafile_with_http_info(self, **kwargs):
        """
        Get a Datafile
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_datafile_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: ID of the datafile to retrieve (required)
        :return: DatafileOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DatafileOutputV1
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_datafile" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_datafile`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/datafiles/{id}', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'DatafileOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_datafiles(self, **kwargs):
        """
        Get a collection of datafiles
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_datafiles(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int offset: The pagination offset, the index of the first collection item that will be returned in this page of results
        :param int limit: The pagination limit, the total number of collection items that will be returned in this page of results
        :return: ItemPreviewListV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ItemPreviewListV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_datafiles_with_http_info(**kwargs)
        else:
            (data) = self.get_datafiles_with_http_info(**kwargs)
            return data

    def get_datafiles_with_http_info(self, **kwargs):
        """
        Get a collection of datafiles
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_datafiles_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int offset: The pagination offset, the index of the first collection item that will be returned in this page of results
        :param int limit: The pagination limit, the total number of collection items that will be returned in this page of results
        :return: ItemPreviewListV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ItemPreviewListV1
        """

        all_params = ['offset', 'limit']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_datafiles" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))
        if 'limit' in params:
            query_params.append(('limit', params['limit']))

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/datafiles', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'ItemPreviewListV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_items_hosted_by_datafile(self, **kwargs):
        """
        Get a list of the items hosted by this datafile
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_items_hosted_by_datafile(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: ID of the datafile (required)
        :param str data_id: The dataId for a specific hosted item
        :param int offset: The pagination offset, the index of the first collection item that will be returned in this page of results
        :param int limit: The pagination limit, the total number of collection items that will be returned in this page of results
        :return: ItemPreviewListV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ItemPreviewListV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_items_hosted_by_datafile_with_http_info(**kwargs)
        else:
            (data) = self.get_items_hosted_by_datafile_with_http_info(**kwargs)
            return data

    def get_items_hosted_by_datafile_with_http_info(self, **kwargs):
        """
        Get a list of the items hosted by this datafile
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_items_hosted_by_datafile_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: ID of the datafile (required)
        :param str data_id: The dataId for a specific hosted item
        :param int offset: The pagination offset, the index of the first collection item that will be returned in this page of results
        :param int limit: The pagination limit, the total number of collection items that will be returned in this page of results
        :return: ItemPreviewListV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ItemPreviewListV1
        """

        all_params = ['id', 'data_id', 'offset', 'limit']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_items_hosted_by_datafile" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_items_hosted_by_datafile`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []
        if 'data_id' in params:
            query_params.append(('dataId', params['data_id']))
        if 'offset' in params:
            query_params.append(('offset', params['offset']))
        if 'limit' in params:
            query_params.append(('limit', params['limit']))

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/datafiles/{id}/items', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'ItemPreviewListV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def import_csv(self, **kwargs):
        """
        Import a CSV file that can be used to create or update a Datafile
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.import_csv(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str file:
        :return: CsvDatafileOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CsvDatafileOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.import_csv_with_http_info(**kwargs)
        else:
            (data) = self.import_csv_with_http_info(**kwargs)
            return data

    def import_csv_with_http_info(self, **kwargs):
        """
        Import a CSV file that can be used to create or update a Datafile
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.import_csv_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str file:
        :return: CsvDatafileOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CsvDatafileOutputV1
        """

        all_params = ['file']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method import_csv" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}
        if 'file' in params:
            local_var_files['file'] = params['file']

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['multipart/form-data', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/datafiles/csv', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'CsvDatafileOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def update_datafile(self, **kwargs):
        """
        Update a datafile
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_datafile(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param DatafileInputV1 body: Datafile information (required)
        :param str id: ID of the datafile to retrieve (required)
        :return: DatafileOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DatafileOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.update_datafile_with_http_info(**kwargs)
        else:
            (data) = self.update_datafile_with_http_info(**kwargs)
            return data

    def update_datafile_with_http_info(self, **kwargs):
        """
        Update a datafile
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_datafile_with_http_info(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param DatafileInputV1 body: Datafile information (required)
        :param str id: ID of the datafile to retrieve (required)
        :return: DatafileOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DatafileOutputV1
        """

        all_params = ['body', 'id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_datafile" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_datafile`")
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `update_datafile`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/datafiles/{id}', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'DatafileOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.10.3-v202502171101-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ColumnRuleInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ancestor': 'ColumnRuleAncestorInputV1',
        'asset_creator': 'ColumnRuleAssetCreatorInputV1',
        'concat_columns': 'ColumnRuleConcatInputV1',
        'constant': 'ColumnRuleConstantInputV1',
        'datasource': 'ColumnRuleDatasourceInputV1',
        'descendant': 'ColumnRuleDescendantInputV1',
        'event_property': 'ColumnRuleEventPropertyInputV1',
        'formula_creator': 'ColumnRuleFormulaCreatorInputV1',
        'get_item_property': 'ColumnRuleGetItemPropertyInputV1',
        'item_search': 'ColumnRuleItemSearchInputV1',
        'item_type': 'ColumnRuleItemTypeInputV1',
        'manager': 'ColumnRuleManagerInputV1',
        'path': 'ColumnRulePathInputV1',
        'path_search': 'ColumnRulePathSearchInputV1',
        'scalar_creator': 'ColumnRuleScalarCreatorInputV1',
        'set_item_property': 'ColumnRuleSetItemPropertyInputV1',
        'text_extractor': 'ColumnRuleTextExtractorInputV1',
        'text_replacement': 'ColumnRuleTextReplacementInputV1',
        'tree_path_creator': 'ColumnRuleTreePathCreatorInputV1'
    }

    attribute_map = {
        'ancestor': 'ancestor',
        'asset_creator': 'assetCreator',
        'concat_columns': 'concatColumns',
        'constant': 'constant',
        'datasource': 'datasource',
        'descendant': 'descendant',
        'event_property': 'eventProperty',
        'formula_creator': 'formulaCreator',
        'get_item_property': 'getItemProperty',
        'item_search': 'itemSearch',
        'item_type': 'itemType',
        'manager': 'manager',
        'path': 'path',
        'path_search': 'pathSearch',
        'scalar_creator': 'scalarCreator',
        'set_item_property': 'setItemProperty',
        'text_extractor': 'textExtractor',
        'text_replacement': 'textReplacement',
        'tree_path_creator': 'treePathCreator'
    }

    def __init__(self, ancestor=None, asset_creator=None, concat_columns=None, constant=None, datasource=None, descendant=None, event_property=None, formula_creator=None, get_item_property=None, item_search=None, item_type=None, manager=None, path=None, path_search=None, scalar_creator=None, set_item_property=None, text_extractor=None, text_replacement=None, tree_path_creator=None):
        """
        ColumnRuleInputV1 - a model defined in Swagger
        """

        self._ancestor = None
        self._asset_creator = None
        self._concat_columns = None
        self._constant = None
        self._datasource = None
        self._descendant = None
        self._event_property = None
        self._formula_creator = None
        self._get_item_property = None
        self._item_search = None
        self._item_type = None
        self._manager = None
        self._path = None
        self._path_search = None
        self._scalar_creator = None
        self._set_item_property = None
        self._text_extractor = None
        self._text_replacement = None
        self._tree_path_creator = None

        if ancestor is not None:
          self.ancestor = ancestor
        if asset_creator is not None:
          self.asset_creator = asset_creator
        if concat_columns is not None:
          self.concat_columns = concat_columns
        if constant is not None:
          self.constant = constant
        if datasource is not None:
          self.datasource = datasource
        if descendant is not None:
          self.descendant = descendant
        if event_property is not None:
          self.event_property = event_property
        if formula_creator is not None:
          self.formula_creator = formula_creator
        if get_item_property is not None:
          self.get_item_property = get_item_property
        if item_search is not None:
          self.item_search = item_search
        if item_type is not None:
          self.item_type = item_type
        if manager is not None:
          self.manager = manager
        if path is not None:
          self.path = path
        if path_search is not None:
          self.path_search = path_search
        if scalar_creator is not None:
          self.scalar_creator = scalar_creator
        if set_item_property is not None:
          self.set_item_property = set_item_property
        if text_extractor is not None:
          self.text_extractor = text_extractor
        if text_replacement is not None:
          self.text_replacement = text_replacement
        if tree_path_creator is not None:
          self.tree_path_creator = tree_path_creator

    @property
    def ancestor(self):
        """
        Gets the ancestor of this ColumnRuleInputV1.

        :return: The ancestor of this ColumnRuleInputV1.
        :rtype: ColumnRuleAncestorInputV1
        """
        return self._ancestor

    @ancestor.setter
    def ancestor(self, ancestor):
        """
        Sets the ancestor of this ColumnRuleInputV1.

        :param ancestor: The ancestor of this ColumnRuleInputV1.
        :type: ColumnRuleAncestorInputV1
        """

        self._ancestor = ancestor

    @property
    def asset_creator(self):
        """
        Gets the asset_creator of this ColumnRuleInputV1.

        :return: The asset_creator of this ColumnRuleInputV1.
        :rtype: ColumnRuleAssetCreatorInputV1
        """
        return self._asset_creator

    @asset_creator.setter
    def asset_creator(self, asset_creator):
        """
        Sets the asset_creator of this ColumnRuleInputV1.

        :param asset_creator: The asset_creator of this ColumnRuleInputV1.
        :type: ColumnRuleAssetCreatorInputV1
        """

        self._asset_creator = asset_creator

    @property
    def concat_columns(self):
        """
        Gets the concat_columns of this ColumnRuleInputV1.

        :return: The concat_columns of this ColumnRuleInputV1.
        :rtype: ColumnRuleConcatInputV1
        """
        return self._concat_columns

    @concat_columns.setter
    def concat_columns(self, concat_columns):
        """
        Sets the concat_columns of this ColumnRuleInputV1.

        :param concat_columns: The concat_columns of this ColumnRuleInputV1.
        :type: ColumnRuleConcatInputV1
        """

        self._concat_columns = concat_columns

    @property
    def constant(self):
        """
        Gets the constant of this ColumnRuleInputV1.

        :return: The constant of this ColumnRuleInputV1.
        :rtype: ColumnRuleConstantInputV1
        """
        return self._constant

    @constant.setter
    def constant(self, constant):
        """
        Sets the constant of this ColumnRuleInputV1.

        :param constant: The constant of this ColumnRuleInputV1.
        :type: ColumnRuleConstantInputV1
        """

        self._constant = constant

    @property
    def datasource(self):
        """
        Gets the datasource of this ColumnRuleInputV1.

        :return: The datasource of this ColumnRuleInputV1.
        :rtype: ColumnRuleDatasourceInputV1
        """
        return self._datasource

    @datasource.setter
    def datasource(self, datasource):
        """
        Sets the datasource of this ColumnRuleInputV1.

        :param datasource: The datasource of this ColumnRuleInputV1.
        :type: ColumnRuleDatasourceInputV1
        """

        self._datasource = datasource

    @property
    def descendant(self):
        """
        Gets the descendant of this ColumnRuleInputV1.

        :return: The descendant of this ColumnRuleInputV1.
        :rtype: ColumnRuleDescendantInputV1
        """
        return self._descendant

    @descendant.setter
    def descendant(self, descendant):
        """
        Sets the descendant of this ColumnRuleInputV1.

        :param descendant: The descendant of this ColumnRuleInputV1.
        :type: ColumnRuleDescendantInputV1
        """

        self._descendant = descendant

    @property
    def event_property(self):
        """
        Gets the event_property of this ColumnRuleInputV1.

        :return: The event_property of this ColumnRuleInputV1.
        :rtype: ColumnRuleEventPropertyInputV1
        """
        return self._event_property

    @event_property.setter
    def event_property(self, event_property):
        """
        Sets the event_property of this ColumnRuleInputV1.

        :param event_property: The event_property of this ColumnRuleInputV1.
        :type: ColumnRuleEventPropertyInputV1
        """

        self._event_property = event_property

    @property
    def formula_creator(self):
        """
        Gets the formula_creator of this ColumnRuleInputV1.

        :return: The formula_creator of this ColumnRuleInputV1.
        :rtype: ColumnRuleFormulaCreatorInputV1
        """
        return self._formula_creator

    @formula_creator.setter
    def formula_creator(self, formula_creator):
        """
        Sets the formula_creator of this ColumnRuleInputV1.

        :param formula_creator: The formula_creator of this ColumnRuleInputV1.
        :type: ColumnRuleFormulaCreatorInputV1
        """

        self._formula_creator = formula_creator

    @property
    def get_item_property(self):
        """
        Gets the get_item_property of this ColumnRuleInputV1.

        :return: The get_item_property of this ColumnRuleInputV1.
        :rtype: ColumnRuleGetItemPropertyInputV1
        """
        return self._get_item_property

    @get_item_property.setter
    def get_item_property(self, get_item_property):
        """
        Sets the get_item_property of this ColumnRuleInputV1.

        :param get_item_property: The get_item_property of this ColumnRuleInputV1.
        :type: ColumnRuleGetItemPropertyInputV1
        """

        self._get_item_property = get_item_property

    @property
    def item_search(self):
        """
        Gets the item_search of this ColumnRuleInputV1.

        :return: The item_search of this ColumnRuleInputV1.
        :rtype: ColumnRuleItemSearchInputV1
        """
        return self._item_search

    @item_search.setter
    def item_search(self, item_search):
        """
        Sets the item_search of this ColumnRuleInputV1.

        :param item_search: The item_search of this ColumnRuleInputV1.
        :type: ColumnRuleItemSearchInputV1
        """

        self._item_search = item_search

    @property
    def item_type(self):
        """
        Gets the item_type of this ColumnRuleInputV1.

        :return: The item_type of this ColumnRuleInputV1.
        :rtype: ColumnRuleItemTypeInputV1
        """
        return self._item_type

    @item_type.setter
    def item_type(self, item_type):
        """
        Sets the item_type of this ColumnRuleInputV1.

        :param item_type: The item_type of this ColumnRuleInputV1.
        :type: ColumnRuleItemTypeInputV1
        """

        self._item_type = item_type

    @property
    def manager(self):
        """
        Gets the manager of this ColumnRuleInputV1.

        :return: The manager of this ColumnRuleInputV1.
        :rtype: ColumnRuleManagerInputV1
        """
        return self._manager

    @manager.setter
    def manager(self, manager):
        """
        Sets the manager of this ColumnRuleInputV1.

        :param manager: The manager of this ColumnRuleInputV1.
        :type: ColumnRuleManagerInputV1
        """

        self._manager = manager

    @property
    def path(self):
        """
        Gets the path of this ColumnRuleInputV1.

        :return: The path of this ColumnRuleInputV1.
        :rtype: ColumnRulePathInputV1
        """
        return self._path

    @path.setter
    def path(self, path):
        """
        Sets the path of this ColumnRuleInputV1.

        :param path: The path of this ColumnRuleInputV1.
        :type: ColumnRulePathInputV1
        """

        self._path = path

    @property
    def path_search(self):
        """
        Gets the path_search of this ColumnRuleInputV1.

        :return: The path_search of this ColumnRuleInputV1.
        :rtype: ColumnRulePathSearchInputV1
        """
        return self._path_search

    @path_search.setter
    def path_search(self, path_search):
        """
        Sets the path_search of this ColumnRuleInputV1.

        :param path_search: The path_search of this ColumnRuleInputV1.
        :type: ColumnRulePathSearchInputV1
        """

        self._path_search = path_search

    @property
    def scalar_creator(self):
        """
        Gets the scalar_creator of this ColumnRuleInputV1.

        :return: The scalar_creator of this ColumnRuleInputV1.
        :rtype: ColumnRuleScalarCreatorInputV1
        """
        return self._scalar_creator

    @scalar_creator.setter
    def scalar_creator(self, scalar_creator):
        """
        Sets the scalar_creator of this ColumnRuleInputV1.

        :param scalar_creator: The scalar_creator of this ColumnRuleInputV1.
        :type: ColumnRuleScalarCreatorInputV1
        """

        self._scalar_creator = scalar_creator

    @property
    def set_item_property(self):
        """
        Gets the set_item_property of this ColumnRuleInputV1.

        :return: The set_item_property of this ColumnRuleInputV1.
        :rtype: ColumnRuleSetItemPropertyInputV1
        """
        return self._set_item_property

    @set_item_property.setter
    def set_item_property(self, set_item_property):
        """
        Sets the set_item_property of this ColumnRuleInputV1.

        :param set_item_property: The set_item_property of this ColumnRuleInputV1.
        :type: ColumnRuleSetItemPropertyInputV1
        """

        self._set_item_property = set_item_property

    @property
    def text_extractor(self):
        """
        Gets the text_extractor of this ColumnRuleInputV1.

        :return: The text_extractor of this ColumnRuleInputV1.
        :rtype: ColumnRuleTextExtractorInputV1
        """
        return self._text_extractor

    @text_extractor.setter
    def text_extractor(self, text_extractor):
        """
        Sets the text_extractor of this ColumnRuleInputV1.

        :param text_extractor: The text_extractor of this ColumnRuleInputV1.
        :type: ColumnRuleTextExtractorInputV1
        """

        self._text_extractor = text_extractor

    @property
    def text_replacement(self):
        """
        Gets the text_replacement of this ColumnRuleInputV1.

        :return: The text_replacement of this ColumnRuleInputV1.
        :rtype: ColumnRuleTextReplacementInputV1
        """
        return self._text_replacement

    @text_replacement.setter
    def text_replacement(self, text_replacement):
        """
        Sets the text_replacement of this ColumnRuleInputV1.

        :param text_replacement: The text_replacement of this ColumnRuleInputV1.
        :type: ColumnRuleTextReplacementInputV1
        """

        self._text_replacement = text_replacement

    @property
    def tree_path_creator(self):
        """
        Gets the tree_path_creator of this ColumnRuleInputV1.

        :return: The tree_path_creator of this ColumnRuleInputV1.
        :rtype: ColumnRuleTreePathCreatorInputV1
        """
        return self._tree_path_creator

    @tree_path_creator.setter
    def tree_path_creator(self, tree_path_creator):
        """
        Sets the tree_path_creator of this ColumnRuleInputV1.

        :param tree_path_creator: The tree_path_creator of this ColumnRuleInputV1.
        :type: ColumnRuleTreePathCreatorInputV1
        """

        self._tree_path_creator = tree_path_creator

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ColumnRuleInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.10.3-v202502171101-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class FormulaDocOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'children': 'list[SeeAlsoDocOutputV1]',
        'constants': 'list[str]',
        'description': 'str',
        'doc_created_at': 'str',
        'doc_updated_at': 'str',
        'documentation_href': 'str',
        'examples': 'list[FormulaExampleOutputV1]',
        'excel_synonyms': 'list[str]',
        'function_group_id': 'str',
        'functions': 'list[FunctionVariantOutputV1]',
        'keywords': 'list[str]',
        'package_created_at': 'str',
        'package_creator_contact_info': 'str',
        'package_creator_name': 'str',
        'package_id': 'str',
        'package_installer_name': 'str',
        'package_updated_at': 'str',
        'package_version': 'str',
        'parameters': 'list[ParameterDocOutputV1]',
        'parents': 'list[SeeAlsoDocOutputV1]',
        'see_alsos': 'list[SeeAlsoDocOutputV1]',
        'title': 'str'
    }

    attribute_map = {
        'children': 'children',
        'constants': 'constants',
        'description': 'description',
        'doc_created_at': 'docCreatedAt',
        'doc_updated_at': 'docUpdatedAt',
        'documentation_href': 'documentationHref',
        'examples': 'examples',
        'excel_synonyms': 'excelSynonyms',
        'function_group_id': 'functionGroupId',
        'functions': 'functions',
        'keywords': 'keywords',
        'package_created_at': 'packageCreatedAt',
        'package_creator_contact_info': 'packageCreatorContactInfo',
        'package_creator_name': 'packageCreatorName',
        'package_id': 'packageId',
        'package_installer_name': 'packageInstallerName',
        'package_updated_at': 'packageUpdatedAt',
        'package_version': 'packageVersion',
        'parameters': 'parameters',
        'parents': 'parents',
        'see_alsos': 'seeAlsos',
        'title': 'title'
    }

    def __init__(self, children=None, constants=None, description=None, doc_created_at=None, doc_updated_at=None, documentation_href=None, examples=None, excel_synonyms=None, function_group_id=None, functions=None, keywords=None, package_created_at=None, package_creator_contact_info=None, package_creator_name=None, package_id=None, package_installer_name=None, package_updated_at=None, package_version=None, parameters=None, parents=None, see_alsos=None, title=None):
        """
        FormulaDocOutputV1 - a model defined in Swagger
        """

        self._children = None
        self._constants = None
        self._description = None
        self._doc_created_at = None
        self._doc_updated_at = None
        self._documentation_href = None
        self._examples = None
        self._excel_synonyms = None
        self._function_group_id = None
        self._functions = None
        self._keywords = None
        self._package_created_at = None
        self._package_creator_contact_info = None
        self._package_creator_name = None
        self._package_id = None
        self._package_installer_name = None
        self._package_updated_at = None
        self._package_version = None
        self._parameters = None
        self._parents = None
        self._see_alsos = None
        self._title = None

        if children is not None:
          self.children = children
        if constants is not None:
          self.constants = constants
        if description is not None:
          self.description = description
        if doc_created_at is not None:
          self.doc_created_at = doc_created_at
        if doc_updated_at is not None:
          self.doc_updated_at = doc_updated_at
        if documentation_href is not None:
          self.documentation_href = documentation_href
        if examples is not None:
          self.examples = examples
        if excel_synonyms is not None:
          self.excel_synonyms = excel_synonyms
        if function_group_id is not None:
          self.function_group_id = function_group_id
        if functions is not None:
          self.functions = functions
        if keywords is not None:
          self.keywords = keywords
        if package_created_at is not None:
          self.package_created_at = package_created_at
        if package_creator_contact_info is not None:
          self.package_creator_contact_info = package_creator_contact_info
        if package_creator_name is not None:
          self.package_creator_name = package_creator_name
        if package_id is not None:
          self.package_id = package_id
        if package_installer_name is not None:
          self.package_installer_name = package_installer_name
        if package_updated_at is not None:
          self.package_updated_at = package_updated_at
        if package_version is not None:
          self.package_version = package_version
        if parameters is not None:
          self.parameters = parameters
        if parents is not None:
          self.parents = parents
        if see_alsos is not None:
          self.see_alsos = see_alsos
        if title is not None:
          self.title = title

    @property
    def children(self):
        """
        Gets the children of this FormulaDocOutputV1.
        Child links of this document

        :return: The children of this FormulaDocOutputV1.
        :rtype: list[SeeAlsoDocOutputV1]
        """
        return self._children

    @children.setter
    def children(self, children):
        """
        Sets the children of this FormulaDocOutputV1.
        Child links of this document

        :param children: The children of this FormulaDocOutputV1.
        :type: list[SeeAlsoDocOutputV1]
        """

        self._children = children

    @property
    def constants(self):
        """
        Gets the constants of this FormulaDocOutputV1.
        Constants provided by this document

        :return: The constants of this FormulaDocOutputV1.
        :rtype: list[str]
        """
        return self._constants

    @constants.setter
    def constants(self, constants):
        """
        Sets the constants of this FormulaDocOutputV1.
        Constants provided by this document

        :param constants: The constants of this FormulaDocOutputV1.
        :type: list[str]
        """

        self._constants = constants

    @property
    def description(self):
        """
        Gets the description of this FormulaDocOutputV1.
        The body of this document

        :return: The description of this FormulaDocOutputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this FormulaDocOutputV1.
        The body of this document

        :param description: The description of this FormulaDocOutputV1.
        :type: str
        """

        self._description = description

    @property
    def doc_created_at(self):
        """
        Gets the doc_created_at of this FormulaDocOutputV1.
        The timestamp that this document was created at

        :return: The doc_created_at of this FormulaDocOutputV1.
        :rtype: str
        """
        return self._doc_created_at

    @doc_created_at.setter
    def doc_created_at(self, doc_created_at):
        """
        Sets the doc_created_at of this FormulaDocOutputV1.
        The timestamp that this document was created at

        :param doc_created_at: The doc_created_at of this FormulaDocOutputV1.
        :type: str
        """

        self._doc_created_at = doc_created_at

    @property
    def doc_updated_at(self):
        """
        Gets the doc_updated_at of this FormulaDocOutputV1.
        The timestamp that this document was last updated at

        :return: The doc_updated_at of this FormulaDocOutputV1.
        :rtype: str
        """
        return self._doc_updated_at

    @doc_updated_at.setter
    def doc_updated_at(self, doc_updated_at):
        """
        Sets the doc_updated_at of this FormulaDocOutputV1.
        The timestamp that this document was last updated at

        :param doc_updated_at: The doc_updated_at of this FormulaDocOutputV1.
        :type: str
        """

        self._doc_updated_at = doc_updated_at

    @property
    def documentation_href(self):
        """
        Gets the documentation_href of this FormulaDocOutputV1.
        The href of this document

        :return: The documentation_href of this FormulaDocOutputV1.
        :rtype: str
        """
        return self._documentation_href

    @documentation_href.setter
    def documentation_href(self, documentation_href):
        """
        Sets the documentation_href of this FormulaDocOutputV1.
        The href of this document

        :param documentation_href: The documentation_href of this FormulaDocOutputV1.
        :type: str
        """

        self._documentation_href = documentation_href

    @property
    def examples(self):
        """
        Gets the examples of this FormulaDocOutputV1.
        Formula examples demonstrating the functions in this document

        :return: The examples of this FormulaDocOutputV1.
        :rtype: list[FormulaExampleOutputV1]
        """
        return self._examples

    @examples.setter
    def examples(self, examples):
        """
        Sets the examples of this FormulaDocOutputV1.
        Formula examples demonstrating the functions in this document

        :param examples: The examples of this FormulaDocOutputV1.
        :type: list[FormulaExampleOutputV1]
        """

        self._examples = examples

    @property
    def excel_synonyms(self):
        """
        Gets the excel_synonyms of this FormulaDocOutputV1.
        Search synonyms for this document, generally corresponding to an excel function

        :return: The excel_synonyms of this FormulaDocOutputV1.
        :rtype: list[str]
        """
        return self._excel_synonyms

    @excel_synonyms.setter
    def excel_synonyms(self, excel_synonyms):
        """
        Sets the excel_synonyms of this FormulaDocOutputV1.
        Search synonyms for this document, generally corresponding to an excel function

        :param excel_synonyms: The excel_synonyms of this FormulaDocOutputV1.
        :type: list[str]
        """

        self._excel_synonyms = excel_synonyms

    @property
    def function_group_id(self):
        """
        Gets the function_group_id of this FormulaDocOutputV1.
        The identifier of this document

        :return: The function_group_id of this FormulaDocOutputV1.
        :rtype: str
        """
        return self._function_group_id

    @function_group_id.setter
    def function_group_id(self, function_group_id):
        """
        Sets the function_group_id of this FormulaDocOutputV1.
        The identifier of this document

        :param function_group_id: The function_group_id of this FormulaDocOutputV1.
        :type: str
        """

        self._function_group_id = function_group_id

    @property
    def functions(self):
        """
        Gets the functions of this FormulaDocOutputV1.
        Functions in this document

        :return: The functions of this FormulaDocOutputV1.
        :rtype: list[FunctionVariantOutputV1]
        """
        return self._functions

    @functions.setter
    def functions(self, functions):
        """
        Sets the functions of this FormulaDocOutputV1.
        Functions in this document

        :param functions: The functions of this FormulaDocOutputV1.
        :type: list[FunctionVariantOutputV1]
        """

        self._functions = functions

    @property
    def keywords(self):
        """
        Gets the keywords of this FormulaDocOutputV1.
        Search keywords for this document

        :return: The keywords of this FormulaDocOutputV1.
        :rtype: list[str]
        """
        return self._keywords

    @keywords.setter
    def keywords(self, keywords):
        """
        Sets the keywords of this FormulaDocOutputV1.
        Search keywords for this document

        :param keywords: The keywords of this FormulaDocOutputV1.
        :type: list[str]
        """

        self._keywords = keywords

    @property
    def package_created_at(self):
        """
        Gets the package_created_at of this FormulaDocOutputV1.
        The timestamp that the Package was created at

        :return: The package_created_at of this FormulaDocOutputV1.
        :rtype: str
        """
        return self._package_created_at

    @package_created_at.setter
    def package_created_at(self, package_created_at):
        """
        Sets the package_created_at of this FormulaDocOutputV1.
        The timestamp that the Package was created at

        :param package_created_at: The package_created_at of this FormulaDocOutputV1.
        :type: str
        """

        self._package_created_at = package_created_at

    @property
    def package_creator_contact_info(self):
        """
        Gets the package_creator_contact_info of this FormulaDocOutputV1.
        The contact information of the Package creator

        :return: The package_creator_contact_info of this FormulaDocOutputV1.
        :rtype: str
        """
        return self._package_creator_contact_info

    @package_creator_contact_info.setter
    def package_creator_contact_info(self, package_creator_contact_info):
        """
        Sets the package_creator_contact_info of this FormulaDocOutputV1.
        The contact information of the Package creator

        :param package_creator_contact_info: The package_creator_contact_info of this FormulaDocOutputV1.
        :type: str
        """

        self._package_creator_contact_info = package_creator_contact_info

    @property
    def package_creator_name(self):
        """
        Gets the package_creator_name of this FormulaDocOutputV1.
        The name of the Package creator

        :return: The package_creator_name of this FormulaDocOutputV1.
        :rtype: str
        """
        return self._package_creator_name

    @package_creator_name.setter
    def package_creator_name(self, package_creator_name):
        """
        Sets the package_creator_name of this FormulaDocOutputV1.
        The name of the Package creator

        :param package_creator_name: The package_creator_name of this FormulaDocOutputV1.
        :type: str
        """

        self._package_creator_name = package_creator_name

    @property
    def package_id(self):
        """
        Gets the package_id of this FormulaDocOutputV1.
        The package containing this document

        :return: The package_id of this FormulaDocOutputV1.
        :rtype: str
        """
        return self._package_id

    @package_id.setter
    def package_id(self, package_id):
        """
        Sets the package_id of this FormulaDocOutputV1.
        The package containing this document

        :param package_id: The package_id of this FormulaDocOutputV1.
        :type: str
        """

        self._package_id = package_id

    @property
    def package_installer_name(self):
        """
        Gets the package_installer_name of this FormulaDocOutputV1.
        The name of the Package installer

        :return: The package_installer_name of this FormulaDocOutputV1.
        :rtype: str
        """
        return self._package_installer_name

    @package_installer_name.setter
    def package_installer_name(self, package_installer_name):
        """
        Sets the package_installer_name of this FormulaDocOutputV1.
        The name of the Package installer

        :param package_installer_name: The package_installer_name of this FormulaDocOutputV1.
        :type: str
        """

        self._package_installer_name = package_installer_name

    @property
    def package_updated_at(self):
        """
        Gets the package_updated_at of this FormulaDocOutputV1.
        The timestamp that the Package was last updated at

        :return: The package_updated_at of this FormulaDocOutputV1.
        :rtype: str
        """
        return self._package_updated_at

    @package_updated_at.setter
    def package_updated_at(self, package_updated_at):
        """
        Sets the package_updated_at of this FormulaDocOutputV1.
        The timestamp that the Package was last updated at

        :param package_updated_at: The package_updated_at of this FormulaDocOutputV1.
        :type: str
        """

        self._package_updated_at = package_updated_at

    @property
    def package_version(self):
        """
        Gets the package_version of this FormulaDocOutputV1.
        The version of the Package

        :return: The package_version of this FormulaDocOutputV1.
        :rtype: str
        """
        return self._package_version

    @package_version.setter
    def package_version(self, package_version):
        """
        Sets the package_version of this FormulaDocOutputV1.
        The version of the Package

        :param package_version: The package_version of this FormulaDocOutputV1.
        :type: str
        """

        self._package_version = package_version

    @property
    def parameters(self):
        """
        Gets the parameters of this FormulaDocOutputV1.
        Parameters of the functions in this document

        :return: The parameters of this FormulaDocOutputV1.
        :rtype: list[ParameterDocOutputV1]
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """
        Sets the parameters of this FormulaDocOutputV1.
        Parameters of the functions in this document

        :param parameters: The parameters of this FormulaDocOutputV1.
        :type: list[ParameterDocOutputV1]
        """

        self._parameters = parameters

    @property
    def parents(self):
        """
        Gets the parents of this FormulaDocOutputV1.
        Parent link of this document

        :return: The parents of this FormulaDocOutputV1.
        :rtype: list[SeeAlsoDocOutputV1]
        """
        return self._parents

    @parents.setter
    def parents(self, parents):
        """
        Sets the parents of this FormulaDocOutputV1.
        Parent link of this document

        :param parents: The parents of this FormulaDocOutputV1.
        :type: list[SeeAlsoDocOutputV1]
        """

        self._parents = parents

    @property
    def see_alsos(self):
        """
        Gets the see_alsos of this FormulaDocOutputV1.
        Related links of this document

        :return: The see_alsos of this FormulaDocOutputV1.
        :rtype: list[SeeAlsoDocOutputV1]
        """
        return self._see_alsos

    @see_alsos.setter
    def see_alsos(self, see_alsos):
        """
        Sets the see_alsos of this FormulaDocOutputV1.
        Related links of this document

        :param see_alsos: The see_alsos of this FormulaDocOutputV1.
        :type: list[SeeAlsoDocOutputV1]
        """

        self._see_alsos = see_alsos

    @property
    def title(self):
        """
        Gets the title of this FormulaDocOutputV1.
        The title of this document

        :return: The title of this FormulaDocOutputV1.
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """
        Sets the title of this FormulaDocOutputV1.
        The title of this document

        :param title: The title of this FormulaDocOutputV1.
        :type: str
        """

        self._title = title

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, FormulaDocOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.10.3-v202502171101-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ReleaseNotesOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'current_release_notes': 'list[IssueSummaryOutputV1]',
        'next_upgrade_time': 'str',
        'next_version': 'str',
        'past_release_notes': 'list[IssueSummaryOutputV1]',
        'upcoming_release_notes': 'list[IssueSummaryOutputV1]'
    }

    attribute_map = {
        'current_release_notes': 'currentReleaseNotes',
        'next_upgrade_time': 'nextUpgradeTime',
        'next_version': 'nextVersion',
        'past_release_notes': 'pastReleaseNotes',
        'upcoming_release_notes': 'upcomingReleaseNotes'
    }

    def __init__(self, current_release_notes=None, next_upgrade_time=None, next_version=None, past_release_notes=None, upcoming_release_notes=None):
        """
        ReleaseNotesOutputV1 - a model defined in Swagger
        """

        self._current_release_notes = None
        self._next_upgrade_time = None
        self._next_version = None
        self._past_release_notes = None
        self._upcoming_release_notes = None

        if current_release_notes is not None:
          self.current_release_notes = current_release_notes
        if next_upgrade_time is not None:
          self.next_upgrade_time = next_upgrade_time
        if next_version is not None:
          self.next_version = next_version
        if past_release_notes is not None:
          self.past_release_notes = past_release_notes
        if upcoming_release_notes is not None:
          self.upcoming_release_notes = upcoming_release_notes

    @property
    def current_release_notes(self):
        """
        Gets the current_release_notes of this ReleaseNotesOutputV1.
        The release notes for the current version

        :return: The current_release_notes of this ReleaseNotesOutputV1.
        :rtype: list[IssueSummaryOutputV1]
        """
        return self._current_release_notes

    @current_release_notes.setter
    def current_release_notes(self, current_release_notes):
        """
        Sets the current_release_notes of this ReleaseNotesOutputV1.
        The release notes for the current version

        :param current_release_notes: The current_release_notes of this ReleaseNotesOutputV1.
        :type: list[IssueSummaryOutputV1]
        """
        if current_release_notes is None:
            raise ValueError("Invalid value for `current_release_notes`, must not be `None`")

        self._current_release_notes = current_release_notes

    @property
    def next_upgrade_time(self):
        """
        Gets the next_upgrade_time of this ReleaseNotesOutputV1.
        The date of the next planned upgrade time, as an ISO-8601 timestamp. May be empty if the server is not on a continuous deployment schedule

        :return: The next_upgrade_time of this ReleaseNotesOutputV1.
        :rtype: str
        """
        return self._next_upgrade_time

    @next_upgrade_time.setter
    def next_upgrade_time(self, next_upgrade_time):
        """
        Sets the next_upgrade_time of this ReleaseNotesOutputV1.
        The date of the next planned upgrade time, as an ISO-8601 timestamp. May be empty if the server is not on a continuous deployment schedule

        :param next_upgrade_time: The next_upgrade_time of this ReleaseNotesOutputV1.
        :type: str
        """

        self._next_upgrade_time = next_upgrade_time

    @property
    def next_version(self):
        """
        Gets the next_version of this ReleaseNotesOutputV1.
        The version that will be installed during the next planned upgrade time. May be empty if the server is not on a continuous deployment schedule

        :return: The next_version of this ReleaseNotesOutputV1.
        :rtype: str
        """
        return self._next_version

    @next_version.setter
    def next_version(self, next_version):
        """
        Sets the next_version of this ReleaseNotesOutputV1.
        The version that will be installed during the next planned upgrade time. May be empty if the server is not on a continuous deployment schedule

        :param next_version: The next_version of this ReleaseNotesOutputV1.
        :type: str
        """

        self._next_version = next_version

    @property
    def past_release_notes(self):
        """
        Gets the past_release_notes of this ReleaseNotesOutputV1.
        The release notes for recently installed versions

        :return: The past_release_notes of this ReleaseNotesOutputV1.
        :rtype: list[IssueSummaryOutputV1]
        """
        return self._past_release_notes

    @past_release_notes.setter
    def past_release_notes(self, past_release_notes):
        """
        Sets the past_release_notes of this ReleaseNotesOutputV1.
        The release notes for recently installed versions

        :param past_release_notes: The past_release_notes of this ReleaseNotesOutputV1.
        :type: list[IssueSummaryOutputV1]
        """
        if past_release_notes is None:
            raise ValueError("Invalid value for `past_release_notes`, must not be `None`")

        self._past_release_notes = past_release_notes

    @property
    def upcoming_release_notes(self):
        """
        Gets the upcoming_release_notes of this ReleaseNotesOutputV1.
        The release notes for the version that will be installed next

        :return: The upcoming_release_notes of this ReleaseNotesOutputV1.
        :rtype: list[IssueSummaryOutputV1]
        """
        return self._upcoming_release_notes

    @upcoming_release_notes.setter
    def upcoming_release_notes(self, upcoming_release_notes):
        """
        Sets the upcoming_release_notes of this ReleaseNotesOutputV1.
        The release notes for the version that will be installed next

        :param upcoming_release_notes: The upcoming_release_notes of this ReleaseNotesOutputV1.
        :type: list[IssueSummaryOutputV1]
        """
        if upcoming_release_notes is None:
            raise ValueError("Invalid value for `upcoming_release_notes`, must not be `None`")

        self._upcoming_release_notes = upcoming_release_notes

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ReleaseNotesOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.10.3-v202502171101-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class FunctionVariantOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'description': 'str',
        'fluent': 'bool',
        'name': 'str',
        'parameters': 'list[FunctionParameterOutputV1]',
        'return_type': 'str',
        'symbolic': 'bool'
    }

    attribute_map = {
        'description': 'description',
        'fluent': 'fluent',
        'name': 'name',
        'parameters': 'parameters',
        'return_type': 'returnType',
        'symbolic': 'symbolic'
    }

    def __init__(self, description=None, fluent=False, name=None, parameters=None, return_type=None, symbolic=False):
        """
        FunctionVariantOutputV1 - a model defined in Swagger
        """

        self._description = None
        self._fluent = None
        self._name = None
        self._parameters = None
        self._return_type = None
        self._symbolic = None

        if description is not None:
          self.description = description
        if fluent is not None:
          self.fluent = fluent
        if name is not None:
          self.name = name
        if parameters is not None:
          self.parameters = parameters
        if return_type is not None:
          self.return_type = return_type
        if symbolic is not None:
          self.symbolic = symbolic

    @property
    def description(self):
        """
        Gets the description of this FunctionVariantOutputV1.
        The description of the function

        :return: The description of this FunctionVariantOutputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this FunctionVariantOutputV1.
        The description of the function

        :param description: The description of this FunctionVariantOutputV1.
        :type: str
        """

        self._description = description

    @property
    def fluent(self):
        """
        Gets the fluent of this FunctionVariantOutputV1.
        True if this function is written in the fluent style

        :return: The fluent of this FunctionVariantOutputV1.
        :rtype: bool
        """
        return self._fluent

    @fluent.setter
    def fluent(self, fluent):
        """
        Sets the fluent of this FunctionVariantOutputV1.
        True if this function is written in the fluent style

        :param fluent: The fluent of this FunctionVariantOutputV1.
        :type: bool
        """

        self._fluent = fluent

    @property
    def name(self):
        """
        Gets the name of this FunctionVariantOutputV1.
        The name of the function

        :return: The name of this FunctionVariantOutputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this FunctionVariantOutputV1.
        The name of the function

        :param name: The name of this FunctionVariantOutputV1.
        :type: str
        """

        self._name = name

    @property
    def parameters(self):
        """
        Gets the parameters of this FunctionVariantOutputV1.
        The parameters of the function

        :return: The parameters of this FunctionVariantOutputV1.
        :rtype: list[FunctionParameterOutputV1]
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """
        Sets the parameters of this FunctionVariantOutputV1.
        The parameters of the function

        :param parameters: The parameters of this FunctionVariantOutputV1.
        :type: list[FunctionParameterOutputV1]
        """

        self._parameters = parameters

    @property
    def return_type(self):
        """
        Gets the return_type of this FunctionVariantOutputV1.
        The type of the function

        :return: The return_type of this FunctionVariantOutputV1.
        :rtype: str
        """
        return self._return_type

    @return_type.setter
    def return_type(self, return_type):
        """
        Sets the return_type of this FunctionVariantOutputV1.
        The type of the function

        :param return_type: The return_type of this FunctionVariantOutputV1.
        :type: str
        """

        self._return_type = return_type

    @property
    def symbolic(self):
        """
        Gets the symbolic of this FunctionVariantOutputV1.
        True if this function is written in the symbolic style

        :return: The symbolic of this FunctionVariantOutputV1.
        :rtype: bool
        """
        return self._symbolic

    @symbolic.setter
    def symbolic(self, symbolic):
        """
        Sets the symbolic of this FunctionVariantOutputV1.
        True if this function is written in the symbolic style

        :param symbolic: The symbolic of this FunctionVariantOutputV1.
        :type: bool
        """

        self._symbolic = symbolic

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, FunctionVariantOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.10.3-v202502171101-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class DebugCacheBlockOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'blocks': 'list[CacheBlock]',
        'read_status': 'str'
    }

    attribute_map = {
        'blocks': 'blocks',
        'read_status': 'readStatus'
    }

    def __init__(self, blocks=None, read_status=None):
        """
        DebugCacheBlockOutputV1 - a model defined in Swagger
        """

        self._blocks = None
        self._read_status = None

        if blocks is not None:
          self.blocks = blocks
        if read_status is not None:
          self.read_status = read_status

    @property
    def blocks(self):
        """
        Gets the blocks of this DebugCacheBlockOutputV1.

        :return: The blocks of this DebugCacheBlockOutputV1.
        :rtype: list[CacheBlock]
        """
        return self._blocks

    @blocks.setter
    def blocks(self, blocks):
        """
        Sets the blocks of this DebugCacheBlockOutputV1.

        :param blocks: The blocks of this DebugCacheBlockOutputV1.
        :type: list[CacheBlock]
        """

        self._blocks = blocks

    @property
    def read_status(self):
        """
        Gets the read_status of this DebugCacheBlockOutputV1.

        :return: The read_status of this DebugCacheBlockOutputV1.
        :rtype: str
        """
        return self._read_status

    @read_status.setter
    def read_status(self, read_status):
        """
        Sets the read_status of this DebugCacheBlockOutputV1.

        :param read_status: The read_status of this DebugCacheBlockOutputV1.
        :type: str
        """
        allowed_values = ["PARTIAL", "COMPLETE", "UNRECOGNIZED"]
        if read_status not in allowed_values:
            raise ValueError(
                "Invalid value for `read_status` ({0}), must be one of {1}"
                .format(read_status, allowed_values)
            )

        self._read_status = read_status

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, DebugCacheBlockOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
